<?php

namespace App\Http\Controllers;


use Illuminate\Http\Request;
use App\patient;
use App\smslog;
use Carbon\Carbon;
use DB;
use Illuminate\Support\Facades\Validator;

class UsersController extends Controller
{
    public function unsubscribeUser(Request $req){ 
        
         // Validation rules
         $rules = [  
            'phoneNumber' => 'required|numeric|digits:10', // Assuming a 10-digit phone number
            'g-recaptcha-response' => 'required'
        ];

        $validator = Validator::make($req->all(), $rules);

        if ($validator->fails()) {
            return response()->json(['message' => $validator->errors()->first(), 'status' => 'fail']);
        }
        
        $secret =  env("RECAPTCHAV3_SECRET", "");
        $postData = array(
                'secret' => $secret,
                'response' =>$req['g-recaptcha-response'],
            );

            $url="https://www.google.com/recaptcha/api/siteverify";

            $ch = curl_init();
            curl_setopt_array($ch, array(
                CURLOPT_URL => $url,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_POST => true,
                CURLOPT_POSTFIELDS => $postData
            ));

            $response = curl_exec($ch);
            $responseData = json_decode($response);
            
            curl_close($ch);
            
        
        if(!$responseData->success){
            return response()->json(['message' => "ReCaptcha Invalid", 'status' => 'fail']);
        }

        $patient = patient::where('phone', $req->phoneNumber)->update(['subscribed' => 0]);
        
        // return redirect()->route('userpage')->with('info', 'Message Schedule is Unsubscribe Successfully');

        return response()->json(['message' => 'Message Schedule is Unsubscribe Successfully', 'status' => 'success']);
    }

    public function saveUser(Request $req){
        try{
            // Validation rules
            $rules = [
                'Name' => 'required|string|max:255',
                'phone' => 'required|numeric|digits:10', // Assuming a 10-digit phone number
                'Start' => 'required|date',
                'End' => 'required|date',
                'Morning' => 'sometimes|in:yes,""',
                'Afternoon' => 'sometimes|in:yes,""',
                'Night' => 'sometimes|in:yes,""',
                'TermsAndCondition' => 'required|in:yes',
                'g-recaptcha-response' => 'required'
            ];

            // Custom validation messages
            $messages = [
                'phone.digits' => 'The phone number must be 10 digits.',
                'TermsAndCondition.accepted' => 'You must accept the terms and conditions.',
            ];

            // Validate the request data
            $validator = Validator::make($req->all(), $rules, $messages);

            // Check if validation fails
            if ($validator->fails()) {
                return response()->json(['message' => $validator->errors()->first(), 'status' => 'fail']);
            }
            
            $secret =  env("RECAPTCHAV3_SECRET", "");
            $postData = array(
                'secret' => $secret,
                'response' =>$req['g-recaptcha-response'],
            );

            $url="https://www.google.com/recaptcha/api/siteverify";

            $ch = curl_init();
            curl_setopt_array($ch, array(
                CURLOPT_URL => $url,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_POST => true,
                CURLOPT_POSTFIELDS => $postData
            ));

            $response = curl_exec($ch);
            $responseData = json_decode($response);
            
            curl_close($ch);
            
        
        if(!$responseData->success){
            return response()->json(['message' => "ReCaptcha Invalid", 'status' => 'fail']);
        }
            
            if(!$responseData->success){
                return response()->json(['message' => "ReCaptcha Invalid", 'status' => 'fail']);
            }
            
            $check = patient::where('phone', $req->phone)->where('subscribed', 1)->first();
            if (empty($check)) {
                $patient = new patient;
                $patient->name = $req->Name;
                $patient->phone = $req->phone;
                $patient->start_date = $req->Start;
                $patient->end_date = $req->End;
                $patient->morning = $req->Morning;
                $patient->afternoon = $req->Afternoon;
                $patient->night = $req->Night;
                $patient->Terms_and_condition = $req->TermsAndCondition;
                $patient->created_at = Carbon::now()->toDateTimeString();
                $patient->updated_at = Carbon::now()->toDateTimeString();
                $patient->save();
                // return redirect()->route('userpage')->with('success', 'Message Schedule Successfully.');
                return response()->json(['message' => 'Thank you for registering with us', 'status' => 'success']);
            } else {
                // return redirect()->route('userpage')->with('error', 'Phone number already exists.');
                return response()->json(['message' => 'You are already registered with us', 'status' => 'fail']);
            }

            
        }catch(Exception $e){
            // return redirect()->route('userpage')->with('error', 'Unsubscribed successfully');
            return response()->json(['message' => $e->getMessage(), 'status' => 'fail']);
        }   
    }    

}
